@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1003';
+our $VERSION = '0.1004';
 
 use strict;
 use warnings;
@@ -314,7 +314,8 @@ sub string_ranger {
     for(1 .. $args{N}) {
         if ($args{type} eq 'pron') {
             push @results, Text::Password::Pronounceable->generate(
-                $args{length}, $args{length});
+                $args{length}, $args{length}
+            );
         }
         else {
             push @results, $sp->make_password($args{length});
@@ -390,7 +391,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1003
+version 0.1004
 
 =head1 SYNOPSIS
 
@@ -459,8 +460,8 @@ are:
 
   stamp: 1 (boolean)
   start: 00-00-00
-  end: now (computed if not given)
-  N: 10
+  end:   now (computed if not given)
+  N:     10
 
 The times must be given as C<HH-MM-SS> strings.  The B<stamp> argument
 determines if a time-stamp or the number of seconds should be returned.
@@ -476,7 +477,7 @@ determines if a time-stamp or the number of seconds should be returned.
   );
 
 Return a list of B<N> random numbers within a range.  The B<start>, B<end>,
-B<prec>ision, whether we want random or sequential numbers, and the desired
+B<prec>ision, whether we want B<random> or sequential numbers, and the desired
 number of data-points are all optional.  The defaults are:
 
   start:     0
@@ -523,13 +524,13 @@ names with unicode are run through L<Text::Unidecode>.
   );
 
 Return a list of B<N> distribution values.  The B<type>, B<prec>ision,
-degrees-of-freedom, and desired number of data-points are optional.  The
-defaults are:
+degrees-of-freedom (B<dof>), and desired number of data-points are optional.
+The defaults are:
 
-  type:               u (normal)
-  precision:          2
-  degrees-of-freedom: 2
-  N:                  10
+  type:      u (normal)
+  precision: 2
+  dof:       2
+  N:         10
 
 This routine uses L<Statistics::Distributions>.
 
@@ -549,8 +550,8 @@ This function uses single letter identifiers:
 Return a shuffled list of B<$n> items.  The B<items> and number of data-points
 are optional.  The defaults are:
 
-  n: 10
   items: a b c d e f g h i j
+  n:     10
 
 =head2 string_ranger()
 
@@ -595,8 +596,8 @@ dimension).  The byte B<size> and number of data-points are both optional.
 
 The defaults are:
 
-  N:    10
   size: 8
+  N:    10
 
 This routine uses L<Image::Dot>.
 
